@@ -1,11 +1,11 @@
 pub trait Sss: Send + Sync + 'static {}
 pub trait SCFunMF<Ctx, Req, Resp>: 'static + Fn(&Ctx, usize, &Req) -> Resp {}
 pub trait SCFunRF<Ctx, Resp>: 'static + Fn(&Ctx, Resp, Resp) -> Resp {}
-pub trait SPFunMF<Req, Resp>: 'static + Fn(usize, &Req) -> Resp {}
-pub trait SPFunRF<Resp>: 'static + Fn(Resp, Resp) -> Resp {}
+// pub trait SPFunMF<Req, Resp>: 'static + Fn(usize, &Req) -> Resp {}
+// pub trait SPFunRF<Resp>: 'static + Fn(Resp, Resp) -> Resp {}
 
 impl<T: Send + Sync + 'static> Sss for T {}
 impl<A, B, C, T: 'static + Fn(&A, usize, &B) -> C> SCFunMF<A, B, C> for T {}
 impl<A, B, T: 'static + Fn(&A, B, B) -> B> SCFunRF<A, B> for T {}
-impl<A, B, T: 'static + Fn(usize, &A) -> B> SPFunMF<A, B> for T {}
-impl<A, T: 'static + Fn(A, A) -> A> SPFunRF<A> for T {}
+// impl<A, B, T: 'static + Fn(usize, &A) -> B> SPFunMF<A, B> for T {}
+// impl<A, T: 'static + Fn(A, A) -> A> SPFunRF<A> for T {}
